From af750de6399d9d1e1bc2d84a52faae8f84fa2364 Mon Sep 17 00:00:00 2001
From: Paul Duncan <pabs@pablotron.org>
Date: Sun, 5 May 2024 11:49:58 -0400
Subject: sha3.c: diet-neon: s/permute_n_neon/permute_n_diet_neon/

---
 sha3.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/sha3.c b/sha3.c
index b2158f5..3101530 100644
--- a/sha3.c
+++ b/sha3.c
@@ -910,8 +910,8 @@ static inline uint64x2_t pi_lo_hi(const uint64x2_t a, const uint64x2_t b) {
   return vextq_u64(c, c, 1);
 }
 
-// neon keccak permutation with inlined steps
-static inline void permute_n_neon(uint64_t a[static 25], const size_t num_rounds) {
+// diet-neon keccak permutation with inlined steps
+static inline void permute_n_diet_neon(uint64_t a[static 25], const size_t num_rounds) {
   // load rows
   row_t r0, r1, r2, r3, r4;
   {
-- 
cgit v1.2.3